async fn current_generation(
store: &MockSuotarStore,
pool: &PgPool,
) -> Result<String, CommandError>Expand description
Builds the world lazily if a command arrives before any contract request has.
async fn current_generation(
store: &MockSuotarStore,
pool: &PgPool,
) -> Result<String, CommandError>Builds the world lazily if a command arrives before any contract request has.