async fn delete_persons(
store: &MockSuotarStore,
generation: &str,
student_numbers: &[String],
) -> Result<Value, CommandError>Expand description
Destructive with no undo: nothing keeps a copy of a person a spec upserted.
async fn delete_persons(
store: &MockSuotarStore,
generation: &str,
student_numbers: &[String],
) -> Result<Value, CommandError>Destructive with no undo: nothing keeps a copy of a person a spec upserted.