pub struct DefaultsPatch {
pub accepted_token: Option<String>,
pub ripeness: Option<Ripeness>,
pub duplicate_detection: Option<DuplicateDetection>,
pub grade_scales: Option<Vec<GradeScale>>,
pub call_log_capacity: Option<usize>,
pub include_non_enrolled_in_result: Option<bool>,
pub realisation_id_required: Option<bool>,
pub static_grade_error_code: Option<String>,
pub clear_static_grade_error_code: bool,
}Fields
accepted_token: Option<String>ripeness: Option<Ripeness>duplicate_detection: Option<DuplicateDetection>grade_scales: Option<Vec<GradeScale>>call_log_capacity: Option<usize>include_non_enrolled_in_result: Option<bool>realisation_id_required: Option<bool>static_grade_error_code: Option<String>clear_static_grade_error_code: boolThe one target field that may itself be None, so an absent key and an explicit null are
otherwise indistinguishable.